@@ -393,7 +393,7 @@ from ae.core import DEBUG_LEVELS, registered_app_names
 from ae.console import ConsoleApp                                                                       # type: ignore
 
 
-__version__ = '0.3.86'
+__version__ = '0.3.87'
 
 
 APP_STATE_SECTION_NAME = 'aeAppState'           #: config section name to store app state
@@ -1408,11 +1408,16 @@ class MainAppBase(ConsoleApp, ABC):
         """
         self.vpo(f"MainAppBase.setup_app_states {app_states}")
 
-        font_size = app_states.get('font_size', 0)
-        if not MIN_FONT_SIZE <= font_size <= MAX_FONT_SIZE:   # adopt device scaling on very first app start
+        # init/add most needed app states (e.g. for self.img_file() calls in .kv with font_size/light_theme bindings)
+        font_size = app_states.get('font_size', 0.0)
+        if not MIN_FONT_SIZE <= font_size <= MAX_FONT_SIZE:
             if font_size < 0.0:
-                font_size = self.dpi_factor() * -font_size
+                font_size = self.dpi_factor() * -font_size      # adopt device scaling on very first app start
+            elif font_size == 0.0:
+                font_size = self.font_size
             app_states['font_size'] = min(max(MIN_FONT_SIZE, font_size), MAX_FONT_SIZE)
+        if 'light_theme' not in app_states:
+            app_states['light_theme'] = self.light_theme
 
         for key, val in app_states.items():
             self.change_app_state(key, val, send_event=False)   # don't send on_-events as framework is not initialized
